@@ -29,6 +29,9 @@
 #define HAVE_ERRNO_H 1
 #define HAVE_SYSEXITS_H 1
 #define C_STACK_GROWS_DOWNWARD 1
+#ifndef __FreeBSD__
+# define C_USE_STD_FEATURE_MACROS
+#endif
 #define C_CHICKEN_PROGRAM "chicken"
 #ifndef C_INSTALL_CC
 # define C_INSTALL_CC "cc"
